@@ -1,7 +1,9 @@
 package WebAPI::DBIC;
-$WebAPI::DBIC::VERSION = '0.003002';
+$WebAPI::DBIC::VERSION = '0.004001';
 use strict; # keep our kwalitee up!
 use warnings;
+
+
 1;
 
 __END__
@@ -16,26 +18,27 @@ WebAPI::DBIC
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 DESCRIPTION
 
-WebAPI::DBIC provides the parts you need to build a feature-rich RESTful JSON web
-service API backed by DBIx::Class schemas.
+WebAPI::DBIC (or "WAPID" for short) provides the parts you need to build a
+feature-rich RESTful JSON web service API backed by DBIx::Class schemas.
 
 WebAPI::DBIC features include:
 
-* Built on the strong foundations of L<Plack> and L<Web::Machine>, plus
-L<Path::Router> as the router. (Other routers could be supported.)
-
 * Built as fine-grained roles for maximum reusability and extensibility.
 
 * Integrates with other L<Plack> based applications.
 
 * The resource roles can be added to your existing application.
 
-* Rich support for multiple hypermedia types, including JSON API
-(application/vnd.api+json) and HAL (application/hal+json).
+* Built on the strong foundations of L<Plack> and L<Web::Machine>, plus
+L<Path::Router> as the router. (Other routers could be supported.)
+
+* Rich support for multiple hypermedia types, including ActiveModel / Ember-Data
+(C<application/json>), JSON API (C<application/vnd.api+json>)
+and HAL (C<application/hal+json>).
 The Collection+JSON and JSON-LD hypermedia types could be added in future.
 
 * Automatic detection and exposure of result set relationships.
@@ -45,67 +48,60 @@ The Collection+JSON and JSON-LD hypermedia types could be added in future.
 * An example .psgi file that gives you an instant web service for any
 DBIx::Class schema.
 
-* Includes a generic HAL API browser application so you can be browsing your
-new API in minutes.
+* A generic pure-javascript HAL API browser application is integrated with
+WebAPI::DBIC so you can be browsing your new API in seconds.
 
-=head2 HAL - Hypertext Application Language
+=head2 Media Types Supported
+
+The HTTP C<Content-Type> and C<Accept> headers are used to specify
+the 'media type' of a request, and the desired response. In the case of JSON
+types, the media type defines not only that the content is a JSON data structure,
+but the semantics (meaning) of the the scructure.
+
+A single application can support requests and responses in multiple media
+types, using the headers to negotiate the right behaviour for ech request.
+
+=head3 ActiveModel
+
+Designed to match the behaviour of the active_model_serializers Ruby gem
+and thus be directly usable as a backend for frameworks compatible with it,
+including Ember.  This uses the C<application/json> media type. (This is a very
+common 'default' media type for web data services.)
+
+See L<WebAPI::DBIC::Resource::ActiveModel> for more information.
+
+=head3 HAL
 
 The Hypertext Application Language hypermedia type (or HAL for short)
 is a simple JSON format that gives a consistent and easy way to hyperlink
-between resources in your API.
+between resources in your API. It uses the C<application/hal+json> media type.
 
-Adopting HAL makes the API explorable, and its documentation easily
-discoverable from within the API itself.  In short, it will make your API
-easier to work with and therefore more attractive to client developers.
+A pure-JavaScript "HAL Browser" application is integrated with the WebAPI::DBIC
+distribution via the L<Alien::Web::HalBrowser> module. It's a great way to
+explore your API.
 
-A JavaScript "HAL Browser" is included in the WebAPI::DBIC distribution.
-(WebAPI::DBIC doesn't yet offer direct support for documentation resources.)
+See L<http://stateless.co/hal_specification.html> for more details of the specification.
+See L<WebAPI::DBIC::Resource::HAL> for more details of WebAPI::DBIC support.
 
-APIs that adopt HAL can be easily served and consumed using open source
-libraries available for most major programming languages. It's also simple
-enough that you can just deal with it as you would any other JSON.
-
-See L<http://stateless.co/hal_specification.html> for more details.
-
-=head2 JSON API
+=head3 JSON API
 
 The JSON API media type is designed to minimize both the number of requests and
 the amount of data transmitted between clients and servers. This efficiency is
 achieved without compromising readability, flexibility, and discoverability.
+It's an (as yet immature) evolution of the ActiveModel media type.
 
-See L<http://jsonapi.org/> for more details.
+See L<WebAPI::DBIC::Resource::JSONAPI> for more details.
 
-For Ember, L<https://github.com/kurko/ember-json-api> can be used as an adaptor.
+=head3 WAPID
 
-STATUS:
-
-Support for JSON API within WebAPI::DBIC is maturing rapidly.
-
-Fetching compound documents, including "links" data (relationship templates)
-and "linked" (side-loaded/prefetch) resources, is supported.
-The sort= parameter is supported, in it's simple form.
-
-Main TO-DOs in approximate order of likely implementation:
-
- - settle on how "type" is defined (currently it's derived from the router)
- - provide "links" separately to prefetch logic
- - support collection urls, e.g. /photos/1,2,3
- - support relationship urls, e.g. /photos/1/links/photographer
- - support include= in addition to prefetch=
- - support multiple sorts, e.g. sort[posts]=-created,title&sort[people]=name
- - support the "name[type]" style of field= param value
- - support creating resources via the application/vnd.api+json media type
- - support updating resources via the application/vnd.api+json media type
- - support updating relationships via the application/vnd.api+json media type
- - support the suggest error format
- - support PATCH requests
+The WebAPI::DBIC core and tests use the C<application/vnd.wapid+json> media
+type. It's subject to change without notice.
 
 =head2 Web::Machine
 
 The L<Web::Machine> module provides a RESTful web framework modeled as a formal
 state machine. This is a rigorous and powerful approach, originally developed
 in Erlang and since ported to many other languages.
-
 See L<https://raw.githubusercontent.com/basho/webmachine/develop/docs/http-headers-status-v3.png>
 for an image of the state machine.
 
@@ -113,13 +109,11 @@ By building on Web::Machine, WebAPI::DBIC removes the need to implement all the
 logic needed for accurate and full-featured HTTP protocol behaviour.
 You just provide small pieces of logic at the decision points you care about
 and Web::Machine looks after the rest.
-
 See L<https://github.com/basho/webmachine/wiki> for more information.
 
 Web::Machine provides the logic to handle a HTTP request for a I<single resource>.
-
 With WebAPI::DBIC those resources typically represent a DBIx::Class result set,
-a row, or a method invocation on a row. They are implemented as a subclass of
+a row, or a method invocation on a row or result set. They are implemented as a subclass of
 L<Web::Machine::Resource> that consumes a some set of WebAPI::DBIC roles which add
 the desired functionality to the resource.
 
@@ -207,6 +201,10 @@ L<WebAPI::DBIC::Resource::Role::ItemInvoke> is responsible for accepting POST
 requests for single item resources representing the invocation of a specific
 method on an item (e.g. POST /widget/42/invoke/my_method_name?args=...).
 
+L<WebAPI::DBIC::Resource::Role::SetInvoke> is responsible for accepting POST
+requests for set resources representing the invocation of a specific
+method on a result set (e.g. POST /widget/invoke/my_method_name?args=...).
+
 L<WebAPI::DBIC::Resource::Role::DBICAuth> is responsible for checking
 authorization to access a resource. It currently supports Basic Authentication,
 using the DBI DSN as the realm name and the return username and password as the
@@ -216,35 +214,17 @@ L<WebAPI::DBIC::Resource::Role::DBICParams> is responsible for handling request
 parameters related to DBIx::Class such as C<page>, C<rows>, C<sort>, C<me>,
 C<prefetch>, C<fields> etc.
 
+=head2 ActiveModel Roles
+
+For support of the C<application/json> media type, see L<WebAPI::DBIC::Resource::ActiveModel>.
+
 =head2 JSON+HAL Roles
 
-These roles are used to handle requests using the C<application/hal+json> media type
-and follow the naming convention used above.
-
-L<WebAPI::DBIC::Resource::HAL::Role::DBIC>
-
-L<WebAPI::DBIC::Resource::HAL::Role::Set>
-
-L<WebAPI::DBIC::Resource::HAL::Role::SetWritable>
-
-L<WebAPI::DBIC::Resource::HAL::Role::Item>
-
-L<WebAPI::DBIC::Resource::HAL::Role::ItemWritable>
+See L<WebAPI::DBIC::Resource::HAL>
 
 =head2 JSON API Roles
 
-These roles are used to handle requests using the C<application/vnd.api+json> media type
-and follow the naming convention used above.
-
-L<WebAPI::DBIC::Resource::JSONAPI::Role::DBIC>
-
-L<WebAPI::DBIC::Resource::JSONAPI::Role::Set>
-
-L<WebAPI::DBIC::Resource::JSONAPI::Role::SetWritable>
-
-L<WebAPI::DBIC::Resource::JSONAPI::Role::Item>
-
-L<WebAPI::DBIC::Resource::JSONAPI::Role::ItemWritable>
+See L<WebAPI::DBIC::Resource::JSONAPI>
 
 =head2 Utility Roles
 
@@ -256,17 +236,21 @@ have their values JSON decoded, so they can be arbitrary data structures.
 
 =head2 Resource Classes
 
-To make building typical applications easier, WebAPI::DBIC provides four
+To make building typical applications easier, WebAPI::DBIC provides several
 pre-defined resource classes:
 
 L<WebAPI::DBIC::Resource::GenericCore> is a base class that consumes all the
 general-purpose resource roles.
 
+L<WebAPI::DBIC::Resource::GenericSet> subclasses GenericCore and consumes extra
+roles for resources represented by a DBIx::Class result set.
+
 L<WebAPI::DBIC::Resource::GenericItem> subclasses GenericCore and consumes
 extra roles for resources represented by an individual DBIx::Class row.
 
-L<WebAPI::DBIC::Resource::GenericSet> subclasses GenericCore and consumes extra
-roles for resources represented by a DBIx::Class result set.
+L<WebAPI::DBIC::Resource::GenericSetInvoke> subclasses GenericCore and
+consumes extra roles for resources that represent a specific method call on a
+set resource.
 
 L<WebAPI::DBIC::Resource::GenericItemInvoke> subclasses GenericCore and
 consumes extra roles for resources that represent a specific method call on an
