@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::GenericItem;
-$WebAPI::DBIC::Resource::GenericItem::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::GenericItem::VERSION = '0.004001';
 
 use Moo;
 use namespace::clean;
@@ -8,6 +8,10 @@ extends 'WebAPI::DBIC::Resource::GenericCore';
 with    'WebAPI::DBIC::Resource::Role::Item',
         'WebAPI::DBIC::Resource::Role::ItemWritable',
         # Enable HAL support:
+        'WebAPI::DBIC::Resource::ActiveModel::Role::DBIC',
+        'WebAPI::DBIC::Resource::ActiveModel::Role::Item',
+        'WebAPI::DBIC::Resource::ActiveModel::Role::ItemWritable',
+        # Enable HAL support:
         'WebAPI::DBIC::Resource::HAL::Role::DBIC',
         'WebAPI::DBIC::Resource::HAL::Role::Item',
         'WebAPI::DBIC::Resource::HAL::Role::ItemWritable',
@@ -31,7 +35,7 @@ WebAPI::DBIC::Resource::GenericItem
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 NAME
 
