@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::GenericSet;
-$WebAPI::DBIC::Resource::GenericSet::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::GenericSet::VERSION = '0.004001';
 
 use Moo;
 use namespace::clean;
@@ -7,6 +7,10 @@ use namespace::clean;
 extends 'WebAPI::DBIC::Resource::GenericCore';
 with    'WebAPI::DBIC::Resource::Role::Set',
         'WebAPI::DBIC::Resource::Role::SetWritable',
+        # Enable ActiveModel support:
+        'WebAPI::DBIC::Resource::ActiveModel::Role::DBIC', # XXX move out?
+        'WebAPI::DBIC::Resource::ActiveModel::Role::Set',
+        'WebAPI::DBIC::Resource::ActiveModel::Role::SetWritable',
         # Enable HAL support:
         'WebAPI::DBIC::Resource::HAL::Role::DBIC', # XXX move out?
         'WebAPI::DBIC::Resource::HAL::Role::Set',
@@ -31,7 +35,7 @@ WebAPI::DBIC::Resource::GenericSet
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 NAME
 
