@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::HAL::Role::Root;
-$WebAPI::DBIC::Resource::HAL::Role::Root::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::HAL::Role::Root::VERSION = '0.004001';
 
 use Moo::Role;
 
@@ -45,7 +45,12 @@ sub render_api_as_hal {
         }
         next unless @parts;
 
-        my $title = join(" ", (split /::/, $route->defaults->{result_class})[-3,-1]);
+        my $title;
+        if (exists $route->defaults->{result_class}) {
+            $title = join(" ", (split /::/, $route->defaults->{result_class})[-3,-1]);
+        } else {
+            ($title) = split( /\?/, $route->path);
+        }
 
         my $url = $path . join("", @parts);
         $links{join("", @parts)} = {
@@ -73,7 +78,7 @@ WebAPI::DBIC::Resource::HAL::Role::Root
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 DESCRIPTION
 
