@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::Role::Item;
-$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.004001';
 
 use Moo::Role;
 
@@ -39,7 +39,7 @@ has content_types_provided => (
 );
 
 sub _build_content_types_provided {
-    return [ { 'application/json' => 'to_json_as_plain' } ]
+    return [ { 'application/vnd.wapid+json' => 'to_json_as_plain' } ]
 }
 
 sub to_json_as_plain { return $_[0]->encode_json($_[0]->render_item_as_plain_hash($_[0]->item)) }
@@ -63,15 +63,13 @@ WebAPI::DBIC::Resource::Role::Item
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 DESCRIPTION
 
 Handles GET and HEAD requests for requests representing individual resources,
 e.g. a single row of a database table.
 
-Supports the C<application/json> content types.
-
 =head1 NAME
 
 WebAPI::DBIC::Resource::Role::Item - methods related to handling requests for item resources
