@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::Role::ItemWritable;
-$WebAPI::DBIC::Resource::Role::ItemWritable::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::Role::ItemWritable::VERSION = '0.004001';
 
 use Carp qw(croak confess);
 use Devel::Dwarn;
@@ -34,7 +34,7 @@ has content_types_accepted => (
 );
 
 sub _build_content_types_accepted {
-    return [ {'application/json' => 'from_plain_json'} ]
+    return [ {'application/vnd.wapid+json' => 'from_plain_json'} ]
 }
 
 
@@ -162,7 +162,7 @@ WebAPI::DBIC::Resource::Role::ItemWritable
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 NAME
 
