@@ -1,7 +1,8 @@
 package WebAPI::DBIC::Resource::Role::Relationship;
-$WebAPI::DBIC::Resource::Role::Relationship::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::Role::Relationship::VERSION = '0.004001';
 
 use Devel::Dwarn;
+use Carp qw(confess);
 use Hash::Util qw(lock_keys);
 
 use Moo::Role;
@@ -11,6 +12,44 @@ requires 'id_column_values_for_item';
 requires 'add_params_to_url';
 
 
+# recurse into a prefetch-like structure invoking a callback
+# XXX still a work in progress, only used by ActiveModule so far
+sub traverse_prefetch {
+    my $self = shift;
+    my $set = shift;
+    my $parent_rel = shift;
+    my $prefetch = shift;
+    my $callback = shift;
+
+    return unless $prefetch;
+
+    if (not ref($prefetch)) { # leaf node
+        $callback->($self, $set, $parent_rel, $prefetch);
+        return;
+    }
+
+    if (ref($prefetch) eq 'HASH') {
+        while (my ($prefetch_key, $prefetch_value) = each(%$prefetch)) {
+            #warn "traverse_prefetch [@$parent_rel] $prefetch\{$prefetch_key}\n";
+            $self->traverse_prefetch($set,             $parent_rel,   $prefetch_key, $callback);
+            # XXX traverse_prefetch first arg is a set but this passes a class:
+            my $result_subclass = $set->result_class->relationship_info($prefetch_key)->{class};
+            $self->traverse_prefetch($result_subclass, [ @$parent_rel, $prefetch_key ], $prefetch_value, $callback);
+        }
+    }
+    elsif (ref($prefetch) eq 'ARRAY') {
+        for my $sub_prefetch (@$prefetch) {
+            $self->traverse_prefetch($set, $parent_rel, $sub_prefetch, $callback);
+        }
+    }
+    else {
+        confess "Unsupported ref(prefetch): " . ref($prefetch);
+    }
+
+    return;
+}
+
+
 our %_get_relationship_link_info_cache;
 
 sub _get_relationship_link_info_cached {
@@ -195,7 +234,7 @@ sub get_url_for_item_relationship {
 
     my $linkurl = $self->uri_for( @uri_for_args );
 
-    if (not $linkurl) {
+    if (not $linkurl) { # XXX this comment is HAL-specific
         warn "Result source $dst_class has no resource uri in this app so relations (like $result_class $relname) won't have _links for it.\n"
             unless our $warn_once->{"$result_class $relname $dst_class"}++;
         return undef;
@@ -292,7 +331,7 @@ WebAPI::DBIC::Resource::Role::Relationship
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 NAME
 
