@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::Role::Set;
-$WebAPI::DBIC::Resource::Role::Set::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::Role::Set::VERSION = '0.004001';
 
 use Moo::Role;
 
@@ -13,7 +13,7 @@ has content_types_provided => (
 );
 
 sub _build_content_types_provided {
-    return [ { 'application/json' => 'to_plain_json'} ]
+    return [ { 'application/vnd.wapid+json' => 'to_plain_json'} ]
 }
 
 sub to_plain_json { return $_[0]->encode_json($_[0]->render_set_as_plain($_[0]->set)) }
@@ -43,7 +43,7 @@ WebAPI::DBIC::Resource::Role::Set
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 DESCRIPTION
 
