@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::Role::SetWritable;
-$WebAPI::DBIC::Resource::Role::SetWritable::VERSION = '0.003002';
+$WebAPI::DBIC::Resource::Role::SetWritable::VERSION = '0.004001';
 
 use Devel::Dwarn;
 use Carp qw(confess);
@@ -26,7 +26,7 @@ has content_types_accepted => (
 );
 
 sub _build_content_types_accepted {
-    return [ {'application/json' => 'from_plain_json'} ]
+    return [ {'application/vnd.wapid+json' => 'from_plain_json'} ]
 }
 
 around 'allowed_methods' => sub {
@@ -86,7 +86,7 @@ WebAPI::DBIC::Resource::Role::SetWritable
 
 =head1 VERSION
 
-version 0.003002
+version 0.004001
 
 =head1 DESCRIPTION
 
